pub struct AsStructured<T>(pub T);Expand description
Wrapper for structured (JSON) output when using #[clap_mcp_output_from].
Use when your run function returns a type that implements Serialize but is not String/&str.
Fully supported when used as the Ok type in Result<AsStructured<T>, E>; there are no known
limitations for mixed success/error types. IntoClapMcpResult is implemented for
AsStructured<T> where T: Serialize.
Example
ⓘ
fn run(cmd: Cli) -> Result<clap_mcp::AsStructured<SubcommandResult>, Error> {
match cmd { ... }
}Tuple Fields
0: TTrait Implementations
Sourceimpl<T: Clone> Clone for AsStructured<T>
impl<T: Clone> Clone for AsStructured<T>
Sourcefn clone(&self) -> AsStructured<T>
fn clone(&self) -> AsStructured<T>
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl<T: Debug> Debug for AsStructured<T>
impl<T: Debug> Debug for AsStructured<T>
Sourceimpl<T: Serialize> IntoClapMcpResult for AsStructured<T>
impl<T: Serialize> IntoClapMcpResult for AsStructured<T>
fn into_tool_result(self) -> Result<ClapMcpToolOutput, ClapMcpToolError>